# Popular Plugins

:::{index} Popular Plugins
:::

In addition to the plugins documented here, our [main plugins directory][plugins] offers a range of tools to extend and
enhance your Arelle experience. For those interested in exploring further, our
[archive plugins directory][plugins-archive] contains a variety of older, less frequently updated plugins. While not
recently tested, these archived plugins may still provide valuable functionality.

:::{toctree}
:maxdepth: 1
arelle_ixbrl_viewer
edgar_renderer
inline_xbrl_document_set
save_loadable_oim
transforms_sec
validation
xule
:::

[plugins]: https://github.com/Arelle/Arelle/tree/master/arelle/plugin
[plugins-archive]: https://github.com/Arelle/Arelle/tree/master/arelle/archive/plugin
